@@ -1,6 +1,5 @@
 # et:ts=4
 # portinstall.tcl
-# $Id: portinstall.tcl 134503 2015-03-27 19:48:17Z cal@macports.org $
 #
 # Copyright (c) 2002 - 2004 Apple Inc.
 # Copyright (c) 2004 Robert Shaw <rshaw@opendarwin.org>
@@ -78,10 +77,9 @@ proc portinstall::install_start {args} {
 
 proc portinstall::create_archive {location archive.type} {
     global workpath destpath portpath subport version revision portvariants \
-           epoch os.platform PortInfo installPlist \
+           epoch PortInfo installPlist \
            archive.env archive.cmd archive.pre_args archive.args \
-           archive.post_args archive.dir \
-           depends_fetch depends_extract depends_build depends_lib depends_run
+           archive.post_args archive.dir depends_lib depends_run
     set archive.env {}
     set archive.cmd {}
     set archive.pre_args {}
@@ -122,7 +120,13 @@ proc portinstall::create_archive {location archive.type} {
                 set archive.pre_args {-cvf}
                 if {[regexp {z2?$} ${archive.type}]} {
                     if {[regexp {bz2?$} ${archive.type}]} {
-                        set gzip "bzip2"
+                        if {![catch {binaryInPath lbzip2}]} {
+                            set gzip "lbzip2"
+                        } elseif {![catch {binaryInPath pbzip2}]} {
+                            set gzip "pbzip2"
+                        } else {
+                            set gzip "bzip2"
+                        }
                         set level 9
                     } elseif {[regexp {lz$} ${archive.type}]} {
                         set gzip "lzma"
@@ -305,10 +309,8 @@ proc portinstall::extract_contents {location type} {
 }
 
 proc portinstall::install_main {args} {
-    global subport version portpath categories description long_description \
-    homepage depends_run package-install workdir workpath \
-    worksrcdir UI_PREFIX destroot revision maintainers user_options \
-    portvariants negated_variants targets depends_lib PortInfo epoch license \
+    global subport version portpath depends_run revision user_options \
+    portvariants negated_variants depends_lib PortInfo epoch \
     os.platform os.major portarchivetype installPlist registry.path porturl
 
     set oldpwd [pwd]
@@ -385,6 +387,7 @@ proc portinstall::install_main {args} {
         set portfile_reg_path ${portfile_reg_dir}/Portfile
         if {![file isfile $portfile_reg_path] || [file size $portfile_reg_path] != $portfile_size || [sha256 file $portfile_reg_path] ne $portfile_sha256} {
             file copy -force $portfile_path $portfile_reg_dir
+            file attributes $portfile_reg_path -permissions 0644
         }
         $regref portfile ${portfile_sha256}-${portfile_size}
 
@@ -403,6 +406,7 @@ proc portinstall::install_main {args} {
                         file mkdir $pg_reg_dir
                         file copy -force $groupFile $pg_reg_dir
                     }
+                    file attributes $pg_reg_path -permissions 0644
                     $regref addgroup $pgname $pgversion $pgsha256 $pgsize
                 } else {
                     ui_debug "install_main: no portgroup ${pgname}-${pgversion}.tcl found"
